# TALKER WITH THE BUTTON
# Include vibration in here


import board
import time
import digitalio
import busio
import neopixel
from adafruit_debouncer import Debouncer
from adafruit_ble import BLERadio
from adafruit_ble.advertising.standard import ProvideServicesAdvertisement
from adafruit_ble.services.nordic import UARTService
from adafruit_bluefruit_connect.packet import Packet
import adafruit_drv2605


ble = BLERadio()
pixels = neopixel.NeoPixel(board.NEOPIXEL, 10, brightness = 0.5, auto_write = True)
uart_connection = None

from adafruit_led_animation.color import (
    AMBER, #(255, 100, 0)
    AQUA, # (50, 255, 255)
    BLACK, #OFF (0, 0, 0)
    BLUE, # (0, 0, 255)
    CYAN, # (0, 255, 255)
    GOLD, # (255, 222, 30)
    GREEN, # (0, 255, 0)
    JADE, # (0, 255, 40)
    MAGENTA, #(255, 0, 20)
    OLD_LACE, # (253, 245, 230)
    ORANGE, # (255, 40, 0)
    PINK, # (242, 90, 255)
    PURPLE, # (180, 0, 255)
    RED, # (255, 0, 0)
    TEAL, # (0, 255, 120)
    WHITE, # (255, 255, 255)
    YELLOW, # (255, 150, 0)
    RAINBOW # a list of colors to cycle through
    ##RAINBOW is RED, ORANGE, YELLOW, GREEN, BLUE, and PURPLE ((255, 0, 0), (255, 40, 0), (255, 150, 0), (0, 255, 0), (0, 0, 255), (180, 0, 255))
)

colors = [RED, MAGENTA, AQUA, TEAL, GREEN]

counter = 0

button_input= digitalio.DigitalInOut(board.A1)
button_input.switch_to_input(pull = digitalio.Pull.UP)

button = Debouncer(button_input)

# Initialize I2C bus and DRV2605 module.
i2c = busio.I2C(board.SCL, board.SDA)
drv = adafruit_drv2605.DRV2605(i2c)


def sequence(numTime):
    for i in range(0,numTime):
        drv.sequence[0] = adafruit_drv2605.Effect(47)
        drv.play()
        time.sleep(0.3)
        drv.stop()
    time.sleep(1.5)



while True:
    if not uart_connection:
        print("Trying to connect...")
        pixels.fill(CYAN)
        for adv in ble.start_scan(ProvideServicesAdvertisement):
            if UARTService in adv.services:
                uart_connection = ble.connect(adv)
                print("Connected")
                break
        ble.stop_scan()

        while not ble.connected:
            pixels.fill((50, 255, 255))

    if uart_connection and uart_connection.connected:
        uart_service = uart_connection[UARTService]
        while uart_connection.connected:
            button.update()
            if button.fell:
                initial = time.monotonic()
            if button.rose:
                if counter == 5:
                    counter = 0
                now = time.monotonic()
                if now - initial > 1:
                    uart_service.write(str(counter-1))
                    print(counter)

                else:
                    print(counter)
                    if counter == 5:
                        counter = 0
                    #shake code
                    if(counter == 0):
                        sequence(1)
                    elif (counter == 1):
                        sequence(2)
                    elif (counter == 2):
                        sequence(3)
                    elif (counter == 3):
                        sequence(4)
                    else:
                        sequence(5)

                    pixels.fill(colors[counter])
                    counter += 1








